==> spatial-hub-0.3.8-exec.jar: BOOT-INF/classes/assets/spApp/spApp.js <==
//# sourceMappingURL=spApp.js.map
void 0===this.SANDBOX_CONFIG&&(SANDBOX_CONFIG={autocompleteColumnHeadersUrl:$SH.sandboxUiUrl+"/dataCheck/autocomplete",biocacheServiceUrl:$SH.sandboxServiceUrl,chartOptionsUrl:$SH.sandboxUiUrl+"/myDatasets/chartOptions",deleteResourceUrl:$SH.sandboxUiUrl+"/myDatasets/deleteResource",getAllDatasetsUrl:$SH.sandboxUiUrl+"/myDatasets/allDatasets",getDatasetsUrl:$SH.sandboxUiUrl+"/myDatasets/userDatasets",keepaliveUrl:$SH.sandboxUiUrl+"/dataCheck/ping",loginUrl:"?service="+$SH.baseUrl,parseColumnsUrl:$SH.sandboxUiUrl+
"/dataCheck/parseColumns",processDataUrl:$SH.sandboxUiUrl+"/dataCheck/processData",reloadDataResourceUrl:$SH.sandboxUiUrl+"/dataCheck/reload",saveChartOptionsUrl:$SH.sandboxUiUrl+"/myDatasets/saveChartOptions",uploadCsvUrl:$SH.sandboxUiUrl+"/dataCheck/uploadFile",uploadToSandboxUrl:$SH.sandboxUiUrl+"/dataCheck/upload",uploadStatusUrl:$SH.sandboxUiUrl+"/dataCheck/uploadStatus",userId:$SH.userId,roles:"ROLE_ADMIN ROLE_API_EDITOR ROLE_APPD_USER ROLE_BASE ROLE_FC_ADMIN ROLE_FC_OFFICER ROLE_SDS_NSW ROLE_SDS_SA ROLE_SDS_VIC ROLE_SDS_WA ROLE_SPATIAL_ADMIN ROLE_SYSTEM_ADMIN ROLE_USER".split(" ")});
$SH.config||($SH.config={});void 0===$SH.config.mapOptions&&($SH.config.mapOptions=!0);void 0===$SH.config.collapseUp&&($SH.config.collapseUp=!0);void 0===$SH.config.collapseLeft&&($SH.config.collapseLeft=!0);void 0===$SH.config.cursorCoordinates&&($SH.config.cursorCoordinates=!0);void 0===$SH.config.quicklinks&&($SH.config.quicklinks=!0);void 0===$SH.config.optionsAddWms&&($SH.config.optionsAddWms=!0);void 0===$SH.config.optionsDownloadMap&&($SH.config.optionsDownloadMap=!0);
void 0===$SH.config.optionsResetMap&&($SH.config.optionsResetMap=!0);void 0===$SH.config.optionsSelectBaseMap&&($SH.config.optionsSelectBaseMap=!0);void 0===$SH.config.layerDistances&&($SH.config.layerDistances=!0);void 0===$SH.config.googleLocation&&($SH.config.googleLocation=!0);void 0===$SH.config.leftPanel&&($SH.config.leftPanel=!0);
var spApp=angular.module("spApp","leaflet-directive ngAnimate ui.bootstrap ui.sortable ui.slider ngRoute ngAnimate chieffancypants.loadingBar ngFileUpload ngTouch ala.sandbox.components ngAria".split(" ").concat($spAppModules)).factory("ConfigService",[function(){return{}}]);spApp.value("sandboxConfig",SANDBOX_CONFIG);spApp.value("existing",1);spApp.config(["$routeProvider",function(a){a.otherwise({templateUrl:"/spApp/spApp.htm",reloadOnSearch:!1})}]);
spApp.config(["$locationProvider",function(a){a.html5Mode({enabled:!0,requireBase:!1})}]);spApp.config(["$logProvider",function(a){a.debugEnabled(!1)}]);
spApp.config(["$httpProvider",function(a){a.interceptors.push(["$q",function(a){return{request:function(b){var a=angular.element(document.querySelector("sp-app")).injector().get("HttpService");a&&a.push(b);return b},requestError:function(b){var d=angular.element(document.querySelector("sp-app")).injector().get("HttpService");d&&d.pop(b,"requestError");return a.reject(b)},response:function(a){var c=angular.element(document.querySelector("sp-app")).injector().get("HttpService");c&&c.pop(a);return a},
responseError:function(b,d,e){if(-1==b.status&&b.config.withCredentials&&void 0===b.config.retried)return d=angular.element(document.querySelector("sp-app")).injector().get("$http"),b.config.retried=!0,d(b.config);(d=angular.element(document.querySelector("sp-app")).injector().get("HttpService"))&&d.pop(b,"responseError");-1!=b.status&&(0===b.status?window.isInWrapper?window.location.href="ios:logout":window.location.reload():404!==b.status&&(b.handled=!0));return a.reject(b)}}}])}]);
spApp.config(["cfpLoadingBarProvider",function(a){a.includeSpinner=!1}]);function isBrowserSupported(){try{return Function("() => {};"),!0}catch(a){return!1}}
function fetchData(){var a=function(a){return{service:"startup",method:a}},c=angular.injector(["ng"]),b=c.get("$http"),d=c.get("$q");c.get("$rootScope");var c=[],e={},f={},g=[];spApp.constant("gLayerDistances",e);spApp.constant("gMessages",f);spApp.constant("gLayers",g);var h=$SH.layersServiceUrl+"/layerDistances/layerdistancesJSON";$SH.config.layerDistances&&b.get(h,a("getLayerDistances")).then(function(a){a.data?$.map(a.data,function(a,b){e[b]=a}):e={}});c.push(b.get($SH.layersServiceUrl+"/fields/search?q=",
a("getLayers")).then(function(a){$.map(a.data,function(a){g.push(a)})}));c.push(b.get($SH.baseUrl+"/portal/i18n?lang="+$SH.i18n,a("geti18n")).then(function(a){for(k in a.data)f[k+""]=a.data[k];$SH.gMessages=f;$i18n=function(a){var b=(""+a).replace(" ","_");return void 0!==$SH.gMessages[b]?$SH.gMessages[b]:a}}));c.push(b.get($SH.baseUrl+"/portal/config/view?hub="+$SH.hub,a("getViewConfig")).then(function(c){$SH.viewConfig=c.data;return b.get($SH.layersServiceUrl+"/capabilities",a("getLayersCapabilities")).then(function(a){var b,
c,f={};for(b in a.data)a.data.hasOwnProperty(b)&&(c=a.data[b],$SH.viewConfig[b]&&(angular.merge(c,$SH.viewConfig[b]),angular.merge(c.input,$SH.viewConfig[b].input)),f[a.data[b].name]=c);$SH.layersServiceCapabilities=f;return d.when(f)})}));return d.all(c).then(function(a){})}
spApp.config(["$provide",function(a){a.decorator("$controller",["$delegate",function(a){return function(b,d,e,f){"string"!==typeof b||d.$scope.controllerName||(d.$scope.componentName=b);return a(b,d,e,f)}}]);$.each(spApp.requires,function(c){c=spApp.requires[c];null!=c.match(/-directive$/g)&&"i18n-directive"!=c&&a.decorator($.camelCase(c),["$delegate","LayoutService",function(a,c){var e=a[0];e.compile=function(){return function(a,b,c){a.componentName=e.name;a._uniqueId&&(a.componentName+=a._uniqueId);
this.link&&this.link.apply(this,arguments)}};return a}])})}]);angular.element($("sp-app")[0]).ready(function(){var a=$("<div ng-view></div>");$("sp-app").append(a);fetchData().then(bootstrapApplication)});function bootstrapApplication(){angular.element($("sp-app")[0]).ready(function(){angular.bootstrap($("sp-app")[0],["spApp"],{strictDi:!0})});$spBootstrapReady()}$spPanelsResized=$spMapLoadedState=$spBootstrapState=!1;$resetMap=void 0;
$spMapLoaded=function(a){$resetMap=a;$spMapLoadedState=!0;setTimeout($spPageLoadingHide,0)};$spBootstrapReady=function(){$spBootstrapState=!0;setTimeout($spPageLoadingHide,0);setTimeout(initLayoutContainer,2E3)};$spPageLoadingHide=function(){$spMapLoadedState&&$spBootstrapState&&$spPanelsResized&&($resetMap(),$(".page-loading").detach(),isBrowserSupported()||$("#browser-supported-message").removeClass("hide"))};spApp.config(["$sceDelegateProvider",function(a){a.resourceUrlWhitelist($SH.validUrls)}]);
spApp.config(["$compileProvider",function(a){a.aHrefSanitizationWhitelist(/^\s*(|blob|http|https):/)}]);resizeSouth=function(a,c,b){$(".ui-layout-resizer")[0].style.marginBottom="-40px";$(".ui-layout-resizer")[0].style.minHeight="40px";$(".ui-layout-resizer")[0].style.background="transparent";$(".ui-layout-resizer")[0].style.maxWidth="350px"};
initLayoutContainer=function(){$SH.config.leftPanel?($("#right-panel")[0].style.marginLeft="420px",$("#left-panel")[0].style.marginLeft="0px"):($("#right-panel")[0].style.marginLeft="0px",$("#left-panel")[0].style.marginLeft="-420px");$(window).on("resize",function(){$(".ui-layout-container")[0]&&($SH.defaultPaneResizer=$(".ui-layout-container").layout({west:{spacing_open:0,spacing_closed:0},east:{spacing_open:0,spacing_closed:0},north:{spacing_open:0,spacing_closed:0},south:{togglerLength_open:0,
togglerLength_closed:0,resizerCursor:"ns-resize",size:$(window).height()-350,spacing_closed:40,onresize:"resizeSouth",minSize:40}}),setTimeout(function(){$("#left-panel")[0].style.maxHeight=$("#map").height()+"px";var a=$("#left-panel .panel-heading:last"),c=$("#left-panel .panel-body:last"),b=$("#left-panel .modal-footer:last");if(0<b.size()&&0<a.size()&&0<c.size()){var d=c.outerHeight()-c.height();c[0].style.maxHeight=$("#map").height()-a.outerHeight()-b.outerHeight()-d+"px"}setTimeout(function(){$SH.defaultPaneResizer.resizeAll()},
100)},100));$("#left-panel")[0].style.maxHeight=$("#map").height()+"px";$spPanelsResized||($spPanelsResized=!0,setTimeout($spPageLoadingHide,0))}).trigger("resize")};L.Icon.Default.imagePath=$SH.baseUrl+"/assets/leaflet/dist/images";jQuery.ui.autocomplete.prototype._resizeMenu=function(){this.menu.element.outerWidth(this.element.outerWidth())};var authWorkaround=function(a){a&&$("body").append('<div style="display:none"><iframe src="'+a+'"></iframe></div>')};$SH.biocollectLoginUrl&&authWorkaround($SH.biocollectLoginUrl);
$SH.layersServiceUrl&&authWorkaround($SH.layersServiceUrl+"/log");L.oldLatLng=L.LatLng;L.LatLng=function(a,c,b){this.lat=parseFloat(a);this.lng=parseFloat(c);void 0!==b&&(L.noConflict.alt=parseFloat(b))};L.extend(L.LatLng,L.oldLatLng);L.LatLng.prototype=L.oldLatLng.prototype;

==> spatial-hub-0.4.2-exec.jar: BOOT-INF/classes/assets/spApp/spApp.js <==
//# sourceMappingURL=spApp.js.map
void 0===this.SANDBOX_CONFIG&&(SANDBOX_CONFIG={autocompleteColumnHeadersUrl:$SH.sandboxUiUrl+"/dataCheck/autocomplete",biocacheServiceUrl:$SH.sandboxServiceUrl,chartOptionsUrl:$SH.sandboxUiUrl+"/myDatasets/chartOptions",deleteResourceUrl:$SH.sandboxUiUrl+"/myDatasets/deleteResource",getAllDatasetsUrl:$SH.sandboxUiUrl+"/myDatasets/allDatasets",getDatasetsUrl:$SH.sandboxUiUrl+"/myDatasets/userDatasets",keepaliveUrl:$SH.sandboxUiUrl+"/dataCheck/ping",loginUrl:"?service="+$SH.baseUrl,parseColumnsUrl:$SH.sandboxUiUrl+
"/dataCheck/parseColumns",processDataUrl:$SH.sandboxUiUrl+"/dataCheck/processData",reloadDataResourceUrl:$SH.sandboxUiUrl+"/dataCheck/reload",saveChartOptionsUrl:$SH.sandboxUiUrl+"/myDatasets/saveChartOptions",uploadCsvUrl:$SH.sandboxUiUrl+"/dataCheck/uploadFile",uploadToSandboxUrl:$SH.sandboxUiUrl+"/dataCheck/upload",uploadStatusUrl:$SH.sandboxUiUrl+"/dataCheck/uploadStatus",userId:$SH.userId,roles:"ROLE_ADMIN ROLE_API_EDITOR ROLE_APPD_USER ROLE_BASE ROLE_FC_ADMIN ROLE_FC_OFFICER ROLE_SDS_NSW ROLE_SDS_SA ROLE_SDS_VIC ROLE_SDS_WA ROLE_SPATIAL_ADMIN ROLE_SYSTEM_ADMIN ROLE_USER".split(" ")});
$SH.config||($SH.config={});void 0===$SH.config.mapOptions&&($SH.config.mapOptions=!0);void 0===$SH.config.collapseUp&&($SH.config.collapseUp=!0);void 0===$SH.config.collapseLeft&&($SH.config.collapseLeft=!0);void 0===$SH.config.cursorCoordinates&&($SH.config.cursorCoordinates=!0);void 0===$SH.config.quicklinks&&($SH.config.quicklinks=!0);void 0===$SH.config.optionsAddWms&&($SH.config.optionsAddWms=!0);void 0===$SH.config.optionsDownloadMap&&($SH.config.optionsDownloadMap=!0);
void 0===$SH.config.optionsResetMap&&($SH.config.optionsResetMap=!0);void 0===$SH.config.optionsSelectBaseMap&&($SH.config.optionsSelectBaseMap=!0);void 0===$SH.config.layerDistances&&($SH.config.layerDistances=!0);void 0===$SH.config.googleLocation&&($SH.config.googleLocation=!0);void 0===$SH.config.leftPanel&&($SH.config.leftPanel=!0);
var spApp=angular.module("spApp","leaflet-directive ngAnimate ui.bootstrap ui.sortable ui.slider ngRoute ngAnimate chieffancypants.loadingBar ngFileUpload ngTouch ala.sandbox.components ngAria".split(" ").concat($spAppModules)).factory("ConfigService",[function(){return{}}]);spApp.value("sandboxConfig",SANDBOX_CONFIG);spApp.value("existing",1);spApp.config(["$routeProvider",function(a){a.otherwise({templateUrl:"/spApp/spApp.htm",reloadOnSearch:!1})}]);
spApp.config(["$locationProvider",function(a){a.html5Mode({enabled:!0,requireBase:!1})}]);spApp.config(["$logProvider",function(a){a.debugEnabled(!1)}]);
spApp.config(["$httpProvider",function(a){a.interceptors.push(["$q",function(a){return{request:function(b){var a=angular.element(document.querySelector("sp-app")).injector().get("HttpService");a&&a.push(b);return b},requestError:function(b){var d=angular.element(document.querySelector("sp-app")).injector().get("HttpService");d&&d.pop(b,"requestError");return a.reject(b)},response:function(b){var a=angular.element(document.querySelector("sp-app")).injector().get("HttpService");a&&a.pop(b);return b},
responseError:function(b,d,e){if(-1==b.status&&b.config.withCredentials&&void 0===b.config.retried)return d=angular.element(document.querySelector("sp-app")).injector().get("$http"),b.config.retried=!0,d(b.config);(d=angular.element(document.querySelector("sp-app")).injector().get("HttpService"))&&d.pop(b,"responseError");403==b.status||401==b.status?(bootbox.alert("Authentication failed or login session expired, Please login again!"),b.handled=!0):-1==b.status?console.log("Cannot connect to: "+b.config.url+
" due to network/connection problems, for example: CORS"):0===b.status&&(window.isInWrapper?window.location.href="ios:logout":window.location.reload());console.log(JSON.stringify(b.data));return a.reject(b)}}}])}]);spApp.config(["cfpLoadingBarProvider",function(a){a.includeSpinner=!1}]);function isBrowserSupported(){try{return Function("() => {};"),!0}catch(a){return!1}}
function fetchData(){var a=function(a){return{service:"startup",method:a}},c=angular.injector(["ng"]),b=c.get("$http"),d=c.get("$q");c.get("$rootScope");var c=[],e={},f={},g=[];spApp.constant("gLayerDistances",e);spApp.constant("gMessages",f);spApp.constant("gLayers",g);var h=$SH.layersServiceUrl+"/layerDistances/layerdistancesJSON";$SH.config.layerDistances&&b.get(h,a("getLayerDistances")).then(function(a){a.data?$.map(a.data,function(a,b){e[b]=a}):e={}});c.push(b.get($SH.layersServiceUrl+"/fields/search?q=",
a("getLayers")).then(function(a){$.map(a.data,function(a){g.push(a)})}));c.push(b.get($SH.baseUrl+"/portal/i18n?lang="+$SH.i18n,a("geti18n")).then(function(a){for(k in a.data)f[k+""]=a.data[k];$SH.gMessages=f;$i18n=function(a){var b=(""+a).replace(" ","_");return void 0!==$SH.gMessages[b]?$SH.gMessages[b]:a}}));c.push(b.get($SH.baseUrl+"/portal/config/view?hub="+$SH.hub,a("getViewConfig")).then(function(c){$SH.viewConfig=c.data;return b.get($SH.layersServiceUrl+"/capabilities",a("getLayersCapabilities")).then(function(a){var b,
c,f={};for(b in a.data)a.data.hasOwnProperty(b)&&(c=a.data[b],$SH.viewConfig[b]&&(angular.merge(c,$SH.viewConfig[b]),angular.merge(c.input,$SH.viewConfig[b].input)),f[a.data[b].name]=c);$SH.layersServiceCapabilities=f;return d.when(f)})}));return d.all(c).then(function(a){})}
spApp.config(["$provide",function(a){a.decorator("$controller",["$delegate",function(a){return function(b,d,e,f){"string"!==typeof b||d.$scope.controllerName||(d.$scope.componentName=b);return a(b,d,e,f)}}]);$.each(spApp.requires,function(c){c=spApp.requires[c];null!=c.match(/-directive$/g)&&"i18n-directive"!=c&&a.decorator($.camelCase(c),["$delegate","LayoutService",function(a,c){var e=a[0];e.compile=function(){return function(a,b,c){a.componentName=e.name;a._uniqueId&&(a.componentName+=a._uniqueId);
this.link&&this.link.apply(this,arguments)}};return a}])})}]);angular.element($("sp-app")[0]).ready(function(){var a=$("<div ng-view></div>");$("sp-app").append(a);fetchData().then(bootstrapApplication)});function bootstrapApplication(){angular.element($("sp-app")[0]).ready(function(){angular.bootstrap($("sp-app")[0],["spApp"],{strictDi:!0})});$spBootstrapReady()}$spPanelsResized=$spMapLoadedState=$spBootstrapState=!1;$resetMap=void 0;
$spMapLoaded=function(a){$resetMap=a;$spMapLoadedState=!0;setTimeout($spPageLoadingHide,0)};$spBootstrapReady=function(){$spBootstrapState=!0;setTimeout($spPageLoadingHide,0);setTimeout(initLayoutContainer,2E3)};$spPageLoadingHide=function(){$spMapLoadedState&&$spBootstrapState&&$spPanelsResized&&($resetMap(),$(".page-loading").detach(),isBrowserSupported()||$("#browser-supported-message").removeClass("hide"))};spApp.config(["$sceDelegateProvider",function(a){a.resourceUrlWhitelist($SH.validUrls)}]);
spApp.config(["$compileProvider",function(a){a.aHrefSanitizationWhitelist(/^\s*(|blob|http|https):/)}]);resizeSouth=function(a,c,b){$(".ui-layout-resizer")[0].style.marginBottom="-40px";$(".ui-layout-resizer")[0].style.minHeight="40px";$(".ui-layout-resizer")[0].style.background="transparent";$(".ui-layout-resizer")[0].style.maxWidth="350px"};
initLayoutContainer=function(){$SH.config.leftPanel?($("#right-panel")[0].style.marginLeft="420px",$("#left-panel")[0].style.marginLeft="0px"):($("#right-panel")[0].style.marginLeft="0px",$("#left-panel")[0].style.marginLeft="-420px");$(window).on("resize",function(){$(".ui-layout-container")[0]&&($SH.defaultPaneResizer=$(".ui-layout-container").layout({west:{spacing_open:0,spacing_closed:0},east:{spacing_open:0,spacing_closed:0},north:{spacing_open:0,spacing_closed:0},south:{togglerLength_open:0,
togglerLength_closed:0,resizerCursor:"ns-resize",size:$(window).height()-350,spacing_closed:40,onresize:"resizeSouth",minSize:40}}),setTimeout(function(){$("#left-panel")[0].style.maxHeight=$("#map").height()+"px";var a=$("#left-panel .panel-heading:last"),c=$("#left-panel .panel-body:last"),b=$("#left-panel .modal-footer:last");if(0<b.size()&&0<a.size()&&0<c.size()){var d=c.outerHeight()-c.height();c[0].style.maxHeight=$("#map").height()-a.outerHeight()-b.outerHeight()-d+"px"}setTimeout(function(){$SH.defaultPaneResizer.resizeAll()},
100)},100));$("#left-panel")[0].style.maxHeight=$("#map").height()+"px";$spPanelsResized||($spPanelsResized=!0,setTimeout($spPageLoadingHide,0))}).trigger("resize")};L.Icon.Default.imagePath=$SH.baseUrl+"/assets/leaflet/dist/images";jQuery.ui.autocomplete.prototype._resizeMenu=function(){this.menu.element.outerWidth(this.element.outerWidth())};var authWorkaround=function(a){a&&$("body").append('<div style="display:none"><iframe src="'+a+'"></iframe></div>')};L.oldLatLng=L.LatLng;
L.LatLng=function(a,c,b){this.lat=parseFloat(a);this.lng=parseFloat(c);void 0!==b&&(L.noConflict.alt=parseFloat(b))};L.extend(L.LatLng,L.oldLatLng);L.LatLng.prototype=L.oldLatLng.prototype;
